@@ -203,6 +203,10 @@ nsUnknownContentTypeDialog.prototype = {
       if (!aLocalFile || !aLocalFile.exists())
         return null;
 
+      // Remove any leading periods, since we don't want to save hidden files
+      // automatically.
+      aLeafName = aLeafName.replace(/^\.+/, "");
+
       if (aLeafName == "")
         aLeafName = "unnamed" + (aFileExt ? "." + aFileExt : "");
       aLocalFile.append(aLeafName);
@@ -356,7 +360,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files. 
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 424 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 428 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       var mimeType = this.mLauncher.MIMEInfo.MIMEType;
       if (mimeType == "application/octet-stream" || 
           mimeType == "application/x-msdownload" ||
@@ -491,12 +495,12 @@ nsUnknownContentTypeDialog.prototype = {
         var result;
 
         // The checking is different on Windows...
-//@line 572 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 576 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
             // On other platforms, default is Ok if there is a default app.
             // Note that nsIMIMEInfo providers need to ensure that this holds true
             // on each platform.
         return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 577 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 581 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
     
     // Set "default" application description field.
@@ -517,9 +521,9 @@ nsUnknownContentTypeDialog.prototype = {
 
     // getPath:
     getPath: function (aFile) {
-//@line 600 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 604 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       return aFile.path;
-//@line 602 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 606 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
 
     // initAppAndSaveToDiskValues:
@@ -587,9 +591,9 @@ nsUnknownContentTypeDialog.prototype = {
       }
       
       // otherHandler is always disabled on Mac
-//@line 673 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 677 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       otherHandler.nextSibling.hidden = otherHandler.nextSibling.nextSibling.hidden = false;
-//@line 675 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 679 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       this.updateOKButton();
     },
 
@@ -742,7 +746,7 @@ nsUnknownContentTypeDialog.prototype = {
           // for the file to be saved to to pass to |saveToDisk| - otherwise
           // we must ask the user to pick a save name.
 
-//@line 841 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 845 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           this.mLauncher.saveToDisk(null, false);
         }
         else
