@@ -850,6 +850,9 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
     return aFile;
 
 //@line 900 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+
+  // Remove leading dots
+  aFile = aFile.replace(/^\.+/, "");
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
