@@ -9,11 +9,11 @@ package org.mozilla.xpcom;
 
 public interface nsIPrefBranch2 extends nsIPrefBranch
 {
-  String NS_IPREFBRANCH2_IID =
+  public static final String NS_IPREFBRANCH2_IID =
     "{74567534-eb94-4b1c-8f45-389643bfc555}";
 
-  void addObserver(String arg1, nsIObserver arg2, boolean arg3);
+  public void addObserver(String arg1, nsIObserver arg2, boolean arg3);
 
-  void removeObserver(String arg1, nsIObserver arg2);
+  public void removeObserver(String arg1, nsIObserver arg2);
 
 }
