@@ -9,13 +9,13 @@ package org.mozilla.xpcom;
 
 public interface nsISupportsPRBool extends nsISupportsPrimitive
 {
-  String NS_ISUPPORTSPRBOOL_IID =
+  public static final String NS_ISUPPORTSPRBOOL_IID =
     "{ddc3b490-4a1c-11d3-9890-006008962422}";
 
-  boolean getData();
+  public boolean getData();
 
-  void setData(boolean arg1);
+  public void setData(boolean arg1);
 
-  String toString();
+  public String toString();
 
 }
