@@ -9,9 +9,9 @@ package org.mozilla.xpcom;
 
 public interface nsITooltipTextProvider extends nsISupports
 {
-  String NS_ITOOLTIPTEXTPROVIDER_IID =
+  public static final String NS_ITOOLTIPTEXTPROVIDER_IID =
     "{b128a1e6-44f3-4331-8fbe-5af360ff21ee}";
 
-  boolean getNodeText(nsIDOMNode arg1, String[] arg2);
+  public boolean getNodeText(nsIDOMNode arg1, String[] arg2);
 
 }
